@@ -57,9 +57,9 @@ launcher_get_screen (Launcher *launcher)
 {
 	PanelWidget *panel_widget;
 
-	g_return_val_if_fail (launcher != NULL, 0);
-	g_return_val_if_fail (launcher->info != NULL, 0);
-	g_return_val_if_fail (launcher->info->widget != NULL, 0);
+	g_return_val_if_fail (launcher != NULL, NULL);
+	g_return_val_if_fail (launcher->info != NULL, NULL);
+	g_return_val_if_fail (launcher->info->widget != NULL, NULL);
 
 	panel_widget = PANEL_WIDGET (launcher->info->widget->parent);
 
@@ -384,7 +384,7 @@ drag_drop_cb (GtkWidget	        *widget,
 	      guint              time,
 	      Launcher          *launcher)
 {
-	static GdkAtom text_uri_list = 0;
+	static GdkAtom text_uri_list = NULL;
 
 	if ( ! is_this_drop_ok (widget, context))
 		return FALSE;
@@ -1119,8 +1119,9 @@ panel_launcher_create_with_id (const char    *toplevel_id,
 	key = panel_gconf_full_key (PANEL_GCONF_OBJECTS, profile, id, "launcher_location");
 	gconf_client_set_string (client, key, location, NULL);
 
-	/* frees id */
 	panel_profile_add_to_list (PANEL_GCONF_OBJECTS, id);
+
+	g_free (id);
 }
 
 void
